Skip to content
Snippets Groups Projects
Commit 0207425f authored by Luis Guzmán's avatar Luis Guzmán
Browse files

Mention distro-info-data dependency.

parent 8ce21fe8
No related branches found
No related tags found
No related merge requests found
File added
diff -Nru source/distro-info-util.c source_b/distro-info-util.c --- source/distro-info-util.c 2021-11-04 15:27:37.000000000 -0600
--- source/distro-info-util.c 2019-03-07 13:33:56.000000000 -0600 +++ source/distro-info-util.c_fix 2022-04-06 10:00:23.394992023 -0500
+++ source_b/distro-info-util.c 2021-12-17 09:47:58.217720979 -0600 @@ -423,10 +423,6 @@
@@ -545,7 +545,7 @@ free(list->distro->milestones[MILESTONE_EOL_LTS]);
free(list->distro->milestones[MILESTONE_EOL_ELTS]);
#endif #endif
" -a --all list all known versions\n" -#ifdef UBUNTU
" -d --devel latest development version\n" - free(list->distro->milestones[MILESTONE_EOL_SERVER]);
- free(list->distro->milestones[MILESTONE_EOL_ESM]);
-#endif
free(list->distro);
free(list);
list = next;
@@ -581,7 +577,7 @@
" -t --testing current testing version\n"
#endif
" -s --stable latest stable version\n"
-#ifdef UBUNTU -#ifdef UBUNTU
+#ifdef TRISQUEL +#ifdef TRISQUEL
" --lts latest long term support (LTS) version\n" " --lts latest long term support (LTS) version\n"
#endif #endif
#ifdef DEBIAN #ifdef DEBIAN
@@ -553,9 +553,6 @@ @@ -592,9 +588,6 @@
" -l --lts list of all LTS supported versions\n"
" -e --elts list of all Extended LTS supported versions\n"
#endif #endif
" -s --stable latest stable version\n"
" --supported list of all supported stable versions\n"
-#ifdef UBUNTU -#ifdef UBUNTU
- " --supported-esm list of all Ubuntu Advantage supported stable versions\n" - " --supported-esm list of all Ubuntu Advantage supported stable versions\n"
-#endif -#endif
" --unsupported list of all unsupported stable versions\n"
" -c --codename print the codename (default)\n"
" -f --fullname print the full name\n"
@@ -612,7 +605,7 @@
#ifdef DEBIAN #ifdef DEBIAN
" -t --testing current testing version\n" "--elts, "
#endif #endif
@@ -573,16 +570,13 @@
"--alias, "
#endif
"--all, --devel, "
-#ifdef UBUNTU -#ifdef UBUNTU
+#ifdef TRISQUEL +#ifdef TRISQUEL
"--latest, --lts, " "--latest, "
#endif #endif
#ifdef DEBIAN "--lts, "
@@ -620,9 +613,6 @@
"--oldstable, " "--oldstable, "
#endif #endif
"--stable, --supported, " "--stable, --supported, "
...@@ -38,7 +49,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c ...@@ -38,7 +49,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c
"--series, " "--series, "
#ifdef DEBIAN #ifdef DEBIAN
"--testing, " "--testing, "
@@ -611,7 +605,7 @@ @@ -651,7 +641,7 @@
#ifdef DEBIAN #ifdef DEBIAN
char *alias_codename = NULL; char *alias_codename = NULL;
#endif #endif
...@@ -47,7 +58,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c ...@@ -47,7 +58,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c
bool filter_latest = false; bool filter_latest = false;
#endif #endif
@@ -624,9 +618,6 @@ @@ -664,9 +654,6 @@
{"devel", no_argument, NULL, 'd' }, {"devel", no_argument, NULL, 'd' },
{"stable", no_argument, NULL, 's' }, {"stable", no_argument, NULL, 's' },
{"supported", no_argument, NULL, 'S' }, {"supported", no_argument, NULL, 'S' },
...@@ -57,7 +68,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c ...@@ -57,7 +68,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c
{"unsupported", no_argument, NULL, 'U' }, {"unsupported", no_argument, NULL, 'U' },
{"codename", no_argument, NULL, 'c' }, {"codename", no_argument, NULL, 'c' },
{"fullname", no_argument, NULL, 'f' }, {"fullname", no_argument, NULL, 'f' },
@@ -636,14 +627,14 @@ @@ -678,14 +665,14 @@
{"oldstable", no_argument, NULL, 'o' }, {"oldstable", no_argument, NULL, 'o' },
{"testing", no_argument, NULL, 't' }, {"testing", no_argument, NULL, 't' },
#endif #endif
...@@ -74,7 +85,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c ...@@ -74,7 +85,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c
const char *short_options = "hadscrfly::"; const char *short_options = "hadscrfly::";
#endif #endif
#ifdef DEBIAN #ifdef DEBIAN
@@ -689,7 +680,7 @@ @@ -731,7 +718,7 @@
case 'd': case 'd':
selected_filters++; selected_filters++;
filter_cb = filter_devel; filter_cb = filter_devel;
...@@ -83,7 +94,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c ...@@ -83,7 +94,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c
select_cb = select_latest_created; select_cb = select_latest_created;
#endif #endif
#ifdef DEBIAN #ifdef DEBIAN
@@ -740,7 +731,7 @@ @@ -782,7 +769,7 @@
free(date); free(date);
return EXIT_SUCCESS; return EXIT_SUCCESS;
...@@ -92,7 +103,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c ...@@ -92,7 +103,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c
case 'l': case 'l':
selected_filters++; selected_filters++;
filter_latest = true; filter_latest = true;
@@ -782,15 +773,6 @@ @@ -836,15 +823,6 @@
select_cb = NULL; select_cb = NULL;
break; break;
...@@ -108,7 +119,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c ...@@ -108,7 +119,7 @@ diff -Nru source/distro-info-util.c source_b/distro-info-util.c
#ifdef DEBIAN #ifdef DEBIAN
case 't': case 't':
selected_filters++; selected_filters++;
@@ -922,7 +904,7 @@ @@ -976,7 +954,7 @@
selected = select_series(distro_list, series_name); selected = select_series(distro_list, series_name);
} else { } else {
selected = get_distro(distro_list, date, filter_cb, select_cb); selected = get_distro(distro_list, date, filter_cb, select_cb);
......
diff -Nru source/python/distro_info.py source_b/python/distro_info.py --- source/python/distro_info.py 2021-11-04 15:27:37.000000000 -0600
--- source/python/distro_info.py 2019-03-07 13:33:56.000000000 -0600 +++ source/python/distro_info.py_fix 2022-04-06 10:20:39.217365952 -0500
+++ source_b/python/distro_info.py 2021-12-17 15:44:54.509722643 -0600
@@ -1,3 +1,4 @@ @@ -1,3 +1,4 @@
+# Copyright (C) 2021, Trisquel GNU/Linux developers <trisquel-devel@listas.trisquel.info> +# Copyright (C) 2021, Trisquel GNU/Linux developers <trisquel-devel@listas.trisquel.info>
# Copyright (C) 2009-2012, Benjamin Drung <bdrung@debian.org> # Copyright (C) 2009-2012, Benjamin Drung <bdrung@debian.org>
...@@ -15,17 +14,17 @@ diff -Nru source/python/distro_info.py source_b/python/distro_info.py ...@@ -15,17 +14,17 @@ diff -Nru source/python/distro_info.py source_b/python/distro_info.py
import csv import csv
import datetime import datetime
@@ -83,7 +84,7 @@ @@ -100,7 +101,7 @@
class DistroInfo(object): class DistroInfo:
"""Base class for distribution information. """Base class for distribution information.
Use DebianDistroInfo or UbuntuDistroInfo instead of using this directly. - Use DebianDistroInfo or UbuntuDistroInfo instead of using this directly.
""" """
def __init__(self, distro): def __init__(self, distro):
@@ -237,14 +238,14 @@ @@ -311,14 +312,14 @@
codename in ["unstable", "testing", "stable", "oldstable"]) ]
-class UbuntuDistroInfo(DistroInfo): -class UbuntuDistroInfo(DistroInfo):
...@@ -34,34 +33,37 @@ diff -Nru source/python/distro_info.py source_b/python/distro_info.py ...@@ -34,34 +33,37 @@ diff -Nru source/python/distro_info.py source_b/python/distro_info.py
+ """provides information about Trisquel's distributions""" + """provides information about Trisquel's distributions"""
def __init__(self): def __init__(self):
- super(UbuntuDistroInfo, self).__init__("Ubuntu") - super().__init__("Ubuntu")
+ super(TrisquelDistroInfo, self).__init__("Trisquel") + super().__init__("Trisquel")
def lts(self, date=None, result="codename"): def lts(self, date=None, result="codename"):
"""Get latest long term support (LTS) Ubuntu distribution based on the - """Get latest long term support (LTS) Ubuntu distribution based on the
given date.""" given date."""
if date is None: if date is None:
date = self._date date = self._date
@@ -262,7 +263,7 @@ @@ -337,7 +338,7 @@
return "LTS" in distros[0].version return "LTS" in distros[0].version
def supported(self, date=None, result="codename"): def supported(self, date=None, result="codename"):
"""Get list of all supported Ubuntu distributions based on the given - """Get list of all supported Ubuntu distributions based on the given
date.""" date."""
if date is None: if date is None:
date = self._date date = self._date
@@ -270,12 +271,3 @@ @@ -347,15 +348,3 @@
if date <= x.eol or if date <= x.eol or (x.eol_server is not None and date <= x.eol_server)
(x.eol_server is not None and date <= x.eol_server)] ]
return distros return distros
- -
- def supported_esm(self, date=None, result="codename"): - def supported_esm(self, date=None, result="codename"):
- """Get list of all ESM supported Ubuntu distributions based on the - """Get list of all ESM supported Ubuntu distributions based on the
- given date.""" - given date."""
- if date is None: - if date is None:
- date = self._date - date = self._date
- distros = [self._format(result, x) for x in self._avail(date) - distros = [
- if x.eol_esm is not None and date <= x.eol_esm] - self._format(result, x)
- for x in self._avail(date)
- if x.eol_esm is not None and date <= x.eol_esm
- ]
- return distros - return distros
...@@ -18,6 +18,7 @@ ...@@ -18,6 +18,7 @@
# #
VERSION=1 VERSION=1
@@ -83,7 +84,7 @@ @@ -100,7 +101,7 @@
class DistroInfo(object): class DistroInfo:
"""Base class for distribution information. """Base class for distribution information.
- Use DebianDistroInfo or UbuntuDistroInfo instead of using this directly. - Use DebianDistroInfo or UbuntuDistroInfo instead of using this directly.
+ Use DebianDistroInfo or TrisquelDistroInfo instead of using this directly. + Use DebianDistroInfo or TrisquelDistroInfo instead of using this directly.
""" """
def __init__(self, distro): def __init__(self, distro):
@@ -237,14 +238,14 @@ @@ -311,14 +312,14 @@
def lts(self, date=None, result="codename"): def lts(self, date=None, result="codename"):
- """Get latest long term support (LTS) Ubuntu distribution based on the - """Get latest long term support (LTS) Ubuntu distribution based on the
+ """Get latest long term support (LTS) Trisquel distribution based on the + """Get latest long term support (LTS) Trisquel distribution based on the
given date.""" given date."""
if date is None: if date is None:
@@ -262,7 +263,7 @@ @@ -337,7 +338,7 @@
return "LTS" in distros[0].version return "LTS" in distros[0].version
def supported(self, date=None, result="codename"): def supported(self, date=None, result="codename"):
- """Get list of all supported Ubuntu distributions based on the given - """Get list of all supported Ubuntu distributions based on the given
+ """Get list of all supported Trisquel distributions based on the given + """Get list of all supported Trisquel distributions based on the given
date.""" date."""
if date is None: if date is None:
DEPENDS=distro-info-data
. ./config . ./config
......
0% Loading or .
You are about to add 0 people to the discussion. Proceed with caution.
Finish editing this message first!
Please register or to comment